if [ ! -v CYGWIN_START_MENU_SUFFIX ]
then
  case $(uname -s) in *-WOW*) CYGWIN_START_MENU_SUFFIX=" (32-bit)" ;; esac
fi

case ${CYGWIN_SETUP_OPTIONS} in
  *no-startmenu*)
  ;;
  *)
  /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}"
  /usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/share/pixmaps/xwin/fluxbox.ico -n "Cygwin-X${CYGWIN_START_MENU_SUFFIX}/Fluxbox" -a "--quote /usr/bin/bash.exe -l -c \"cd; XSESSION_ICON=fluxbox exec /usr/bin/startx /etc/X11/xinit/Xsession fluxbox\"" /usr/bin/run.exe
  ;;
esac
